@@ -200,6 +200,8 @@ def init_test_database(config=None, configdir='data'):
         init_test_database_sqlite(config)
     elif driver == 'postgres':
         init_test_database_postgres(config)
+    elif driver == 'sqlserver2005':
+        init_test_database_sqlserver2005(config)
     else:
         raise ValueError('no initialization function for driver %r' % driver)
     config._cubes = None # avoid assertion error
@@ -215,6 +217,10 @@ def reset_test_database(config):
     driver = config.sources()['system']['db-driver']
     if driver == 'sqlite':
         reset_test_database_sqlite(config)
+    elif driver in ('sqlserver2005', 'postgres'):
+        # XXX do something with dump/restore ?
+        print 'resetting the database is not done for', driver
+        print 'you should handle it manually'
     else:
         raise ValueError('no reset function for driver %r' % driver)
 
@@ -222,11 +228,18 @@ def reset_test_database(config):
 ### postgres test database handling ############################################
 
 def init_test_database_postgres(config):
-    """initialize a fresh sqlite databse used for testing purpose"""
+    """initialize a fresh postgresql databse used for testing purpose"""
     if config.init_repository:
         from cubicweb.server import init_repository
         init_repository(config, interactive=False, drop=True)
 
+### sqlserver2005 test database handling ############################################
+
+def init_test_database_sqlserver2005(config):
+    """initialize a fresh sqlserver databse used for testing purpose"""
+    if config.init_repository:
+        from cubicweb.server import init_repository
+        init_repository(config, interactive=False, drop=True, vreg=vreg)
 
 ### sqlite test database handling ##############################################
 
