@@ -132,17 +132,16 @@ class CubicWebTC(TestCase):
     """abstract class for test using an apptest environment
 
     attributes:
-    `vreg`, the vregistry
-    `schema`, self.vreg.schema
-    `config`, cubicweb configuration
-    `cnx`, dbapi connection to the repository using an admin user
-    `session`, server side session associated to `cnx`
-    `app`, the cubicweb publisher (for web testing)
-    `repo`, the repository object
-
-    `admlogin`, login of the admin user
-    `admpassword`, password of the admin user
 
+    * `vreg`, the vregistry
+    * `schema`, self.vreg.schema
+    * `config`, cubicweb configuration
+    * `cnx`, dbapi connection to the repository using an admin user
+    * `session`, server side session associated to `cnx`
+    * `app`, the cubicweb publisher (for web testing)
+    * `repo`, the repository object
+    * `admlogin`, login of the admin user
+    * `admpassword`, password of the admin user
     """
     appid = 'data'
     configcls = devtools.ApptestConfiguration
@@ -261,6 +260,12 @@ class CubicWebTC(TestCase):
         self.setup_database()
         self.commit()
         MAILBOX[:] = [] # reset mailbox
+        self._cnxs = []
+
+    def tearDown(self):
+        for cnx in self._cnxs:
+            if not cnx._closed:
+                cnx.close()
 
     def setup_database(self):
         """add your database setup code by overriding this method"""
@@ -302,6 +307,7 @@ class CubicWebTC(TestCase):
             self.cnx = repo_connect(self.repo, unicode(login),
                                     cnxprops=ConnectionProperties('inmemory'),
                                     **kwargs)
+            self._cnxs.append(self.cnx)
         if login == self.vreg.config.anonymous_user()[0]:
             self.cnx.anonymous_connection = True
         return self.cnx
@@ -310,6 +316,7 @@ class CubicWebTC(TestCase):
         if not self.cnx is self._orig_cnx:
             try:
                 self.cnx.close()
+                self._cnxs.remove(self.cnx)
             except ProgrammingError:
                 pass # already closed
         self.cnx = self._orig_cnx
@@ -360,9 +367,11 @@ class CubicWebTC(TestCase):
         self.vreg._loadedmods.setdefault(self.__module__, {})
         for obj in appobjects:
             self.vreg.register(obj)
-        yield
-        for obj in appobjects:
-            self.vreg.unregister(obj)
+        try:
+            yield
+        finally:
+            for obj in appobjects:
+                self.vreg.unregister(obj)
 
     # vregistry inspection utilities ###########################################
 
@@ -483,9 +492,9 @@ class CubicWebTC(TestCase):
     def app_publish(self, req, path='view'):
         return self.app.publish(path, req)
 
-    def ctrl_publish(self, req):
+    def ctrl_publish(self, req, ctrl='edit'):
         """call the publish method of the edit controller"""
-        ctrl = self.vreg['controllers'].select('edit', req)
+        ctrl = self.vreg['controllers'].select(ctrl, req)
         try:
             result = ctrl.publish()
             req.cnx.commit()
