@@ -179,7 +179,7 @@ class CubicWebRootResource(resource.PostableResource):
         """Render a page from the root resource"""
         # reload modified files in debug mode
         if self.debugmode:
-            self.appli.vreg.register_objects(self.config.vregistry_path())
+            self.appli.vreg.reload_if_needed()
         if self.config['profile']: # default profiler don't trace threads
             return self.render_request(request)
         else:
@@ -283,11 +283,11 @@ class CubicWebRootResource(resource.PostableResource):
 from twisted.internet import defer
 from twisted.web2 import fileupload
 
-# XXX set max file size to 100Mo: put max upload size in the configuration
+# XXX set max file size to 200MB: put max upload size in the configuration
 # line below for twisted >= 8.0, default param value for earlier version
-resource.PostableResource.maxSize = 100*1024*1024
+resource.PostableResource.maxSize = 200*1024*1024
 def parsePOSTData(request, maxMem=100*1024, maxFields=1024,
-                  maxSize=100*1024*1024):
+                  maxSize=200*1024*1024):
     if request.stream.length == 0:
         return defer.succeed(None)
 
