@@ -713,7 +713,14 @@ class ServerMigrationHelper(MigrationHelper):
         execute = self._cw.execute
         ss.execschemarql(execute, eschema, ss.eschema2rql(eschema, groupmap))
         # add specializes relation if needed
-        self.rqlexecall(ss.eschemaspecialize2rql(eschema), ask_confirm=confirm)
+        specialized = eschema.specializes()
+        if specialized:
+            try:
+                specialized.eid = instschema[specialized].eid
+            except KeyError:
+                raise Exception('trying to add entity type but parent type is '
+                                'not yet in the database schema')
+            self.rqlexecall(ss.eschemaspecialize2rql(eschema), ask_confirm=confirm)
         # register entity's attributes
         for rschema, attrschema in eschema.attribute_definitions():
             # ignore those meta relations, they will be automatically added
@@ -976,7 +983,13 @@ class ServerMigrationHelper(MigrationHelper):
                 if syncprops:
                     self._synchronize_eschema(etype, syncperms=syncperms)
                 else:
-                    self._synchronize_permissions(self.fs_schema[etype], etype.eid)
+                    try:
+                        fseschema = self.fs_schema[etype]
+                    except KeyError:
+                        # entity type in the repository schema but not anymore
+                        # on the fs schema
+                        continue
+                    self._synchronize_permissions(fseschema, etype.eid)
         if commit:
             self.commit()
 
@@ -1167,9 +1180,8 @@ class ServerMigrationHelper(MigrationHelper):
             return session
         return self.cnx.request()
 
-    def cmd_create_entity(self, etype, **kwargs):
+    def cmd_create_entity(self, etype, commit=False, **kwargs):
         """add a new entity of the given type"""
-        commit = kwargs.pop('commit', False)
         entity = self._cw.create_entity(etype, **kwargs)
         if commit:
             self.commit()
