@@ -276,7 +276,7 @@ class Session(RequestSessionBase):
 
     def system_sql(self, sql, args=None, rollback_on_failure=True):
         """return a sql cursor on the system database"""
-        if not sql.split(None, 1)[0].upper() == 'SELECT':
+        if sql.split(None, 1)[0].upper() != 'SELECT':
             self.mode = 'write'
         source = self.pool.source('system')
         try:
@@ -896,7 +896,8 @@ class Session(RequestSessionBase):
     # deprecated ###############################################################
 
     @deprecated("[3.7] execute is now unsafe by default in hooks/operation. You"
-                " can also control security with session.[read|write]_security")
+                " can also control security with the security_enabled context "
+                "manager")
     def unsafe_execute(self, rql, kwargs=None, eid_key=None, build_descr=True,
                        propagate=False):
         """like .execute but with security checking disabled (this method is
@@ -945,6 +946,7 @@ class Session(RequestSessionBase):
 class InternalSession(Session):
     """special session created internaly by the repository"""
     is_internal_session = True
+    running_dbapi_query = False
 
     def __init__(self, repo, cnxprops=None):
         super(InternalSession, self).__init__(InternalManager(), repo, cnxprops,
