@@ -471,21 +471,25 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
         #    on the filesystem. To make the entity.data usage absolutely
         #    transparent, we'll have to reset entity.data to its binary
         #    value once the SQL query will be executed
-        orig_values = {}
+        restore_values = {}
         etype = entity.__regid__
         for attr, storage in self._storages.get(etype, {}).items():
             try:
-                if attr in entity.edited_attributes:
-                    orig_values[attr] = entity[attr]
-                    handler = getattr(storage, 'entity_%s' % event)
-                    handler(entity, attr)
+                edited = entity.edited_attributes
             except AttributeError:
                 assert event == 'deleted'
                 getattr(storage, 'entity_deleted')(entity, attr)
-        yield # 2/ execute the source's instructions
-        # 3/ restore original values
-        for attr, value in orig_values.items():
-            entity[attr] = value
+            else:
+                if attr in edited:
+                    handler = getattr(storage, 'entity_%s' % event)
+                    real_value = handler(entity, attr)
+                    restore_values[attr] = real_value
+        try:
+            yield # 2/ execute the source's instructions
+        finally:
+            # 3/ restore original values
+            for attr, value in restore_values.items():
+                entity[attr] = value
 
     def add_entity(self, session, entity):
         """add a new entity to the source"""
@@ -667,6 +671,15 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
             pass
         return None
 
+    def make_temp_table_name(self, table):
+        try: # XXX remove this once 
+            return self.dbhelper.temporary_table_name(table)
+        except AttributeError:
+            import warnings
+            warnings.warn('Please hg up logilab.database')
+            return table
+
+
     def temp_table_def(self, selected, sol, table):
         return make_schema(selected, sol, table, self.dbhelper.TYPE_MAPPING)
 
@@ -1237,9 +1250,9 @@ def sql_drop_schema(driver):
 %s
 DROP TABLE entities;
 DROP TABLE deleted_entities;
-DROP TABLE transactions;
 DROP TABLE tx_entity_actions;
 DROP TABLE tx_relation_actions;
+DROP TABLE transactions;
 """ % helper.sql_drop_sequence('entities_id_seq')
 
 
