@@ -136,6 +136,9 @@ class Controller(AppObject):
             params.update(newparams)
             newparams = params
         elif self._edited_entity:
+            # clear caches in case some attribute participating to the rest path
+            # has been modified
+            self._edited_entity.clear_all_caches()
             path = self._edited_entity.rest_path()
         else:
             path = 'view'
